summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJohnny Willemsen <jwillemsen@remedy.nl>2007-11-01 12:00:11 +0000
committerJohnny Willemsen <jwillemsen@remedy.nl>2007-11-01 12:00:11 +0000
commit8ae2f82db8d6a8eb39adcb04155a2d7bbf9c6365 (patch)
treefbb63ea3424c273891171efe10569ea3bdf9413b
parent6184ced2c95439444c6a05bbb04b42a81b524d96 (diff)
downloadATCD-8ae2f82db8d6a8eb39adcb04155a2d7bbf9c6365.tar.gz
Thu Nov 1 11:59:15 UTC 2007 Johnny Willemsen <jwillemsen@remedy.nl>
-rw-r--r--ACE/ChangeLog10
-rw-r--r--ACE/ace/Select_Reactor_T.h4
-rw-r--r--ACE/ace/Timer_Queue_T.cpp3
-rw-r--r--ACE/ace/Timer_Queue_T.h10
-rw-r--r--ACE/ace/Timer_Wheel_T.h4
5 files changed, 20 insertions, 11 deletions
diff --git a/ACE/ChangeLog b/ACE/ChangeLog
index 2a4b14c4fd4..46910467906 100644
--- a/ACE/ChangeLog
+++ b/ACE/ChangeLog
@@ -1,3 +1,13 @@
+Thu Nov 1 11:59:15 UTC 2007 Johnny Willemsen <jwillemsen@remedy.nl>
+
+ * ace/Select_Reactor_T.h:
+ * ace/Timer_Queue_T.h:
+ * ace/Timer_Wheel_T.h:
+ Doxygen changes
+
+ * ace/Timer_Queue_T.cpp:
+ Layout change
+
Thu Nov 1 11:11:15 UTC 2007 Johnny Willemsen <jwillemsen@remedy.nl>
* ace/Service_Config.h:
diff --git a/ACE/ace/Select_Reactor_T.h b/ACE/ace/Select_Reactor_T.h
index 6ba0ef571dc..332ad9718d9 100644
--- a/ACE/ace/Select_Reactor_T.h
+++ b/ACE/ace/Select_Reactor_T.h
@@ -373,7 +373,7 @@ public:
/**
* Cancel all <event_handlers> that match the address of
- * <event_handler>. If <dont_call_handle_close> is 0 then the
+ * <event_handler>. If @a dont_call_handle_close is 0 then the
* <handle_close> method of <event_handler> will be invoked.
* Returns number of handler's cancelled.
*/
@@ -386,7 +386,7 @@ public:
* non-NULL then it will be set to point to the ``magic cookie''
* argument passed in when the <Event_Handler> was registered. This
* makes it possible to free up the memory and avoid memory leaks.
- * If <dont_call_handle_close> is 0 then the <handle_close> method
+ * If @a dont_call_handle_close is 0 then the <handle_close> method
* of <event_handler> will be invoked. Returns 1 if cancellation
* succeeded and 0 if the @a timer_id wasn't found.
*/
diff --git a/ACE/ace/Timer_Queue_T.cpp b/ACE/ace/Timer_Queue_T.cpp
index b7cf0bb40dd..4643090ecd5 100644
--- a/ACE/ace/Timer_Queue_T.cpp
+++ b/ACE/ace/Timer_Queue_T.cpp
@@ -265,8 +265,7 @@ ACE_Timer_Queue_T<TYPE, FUNCTOR, ACE_LOCK>::expire (const ACE_Time_Value &cur_ti
ACE_Timer_Node_Dispatch_Info_T<TYPE> info;
- while ((result = this->dispatch_info_i (cur_time,
- info)) != 0)
+ while ((result = this->dispatch_info_i (cur_time, info)) != 0)
{
const void *upcall_act = 0;
diff --git a/ACE/ace/Timer_Queue_T.h b/ACE/ace/Timer_Queue_T.h
index ced92db6181..8aef637579e 100644
--- a/ACE/ace/Timer_Queue_T.h
+++ b/ACE/ace/Timer_Queue_T.h
@@ -263,7 +263,7 @@ public:
/**
* Cancel all timer associated with @a type. If
- * <dont_call_handle_close> is 0 then the <functor> will be invoked,
+ * @a dont_call_handle_close is 0 then the <functor> will be invoked,
* which typically invokes the <handle_close> hook. Returns number
* of timers cancelled.
*/
@@ -276,7 +276,7 @@ public:
* then it will be set to point to the ``magic cookie'' argument
* passed in when the timer was registered. This makes it possible
* to free up the memory and avoid memory leaks. If
- * <dont_call_handle_close> is 0 then the <functor> will be invoked,
+ * @a dont_call_handle_close is 0 then the <functor> will be invoked,
* which typically calls the <handle_close> hook. Returns 1 if
* cancellation succeeded and 0 if the @a timer_id wasn't found.
*/
@@ -285,16 +285,16 @@ public:
int dont_call_handle_close = 1) = 0;
/**
- * Run the <functor> for all timers whose values are <= <cur_time>.
+ * Run the <functor> for all timers whose values are <= @a current_time.
* This does not account for <timer_skew>. Returns the number of
* timers canceled.
*/
virtual int expire (const ACE_Time_Value &current_time);
/**
- * Get the dispatch information for a timer whose value is <= <cur_time>.
+ * Get the dispatch information for a timer whose value is <= @a current_time.
* This does not account for <timer_skew>. Returns 1 if
- * there is a node whose value <= <cur_time> else returns a 0.
+ * there is a node whose value <= @a current_time else returns a 0.
*
*/
virtual int dispatch_info (const ACE_Time_Value &current_time,
diff --git a/ACE/ace/Timer_Wheel_T.h b/ACE/ace/Timer_Wheel_T.h
index c9d07312312..c30587594a5 100644
--- a/ACE/ace/Timer_Wheel_T.h
+++ b/ACE/ace/Timer_Wheel_T.h
@@ -144,10 +144,10 @@ public:
/// the number of timers canceled.
virtual int expire (void);
// Run the <functor> for all timers whose values are <= <cur_time>.
// This does not account for <timer_skew>. Returns the number of
// timers canceled.
- int expire (const ACE_Time_Value&);
+ int expire (const ACE_Time_Value& current_time);
/// Returns a pointer to this <ACE_Timer_Queue_T>'s iterator.
virtual ACE_Timer_Queue_Iterator_T<TYPE, FUNCTOR, ACE_LOCK>& iter (void);
@@ -144,10 +144,10 @@ public:
/// the number of timers canceled.
virtual int expire (void);
- // Run the <functor> for all timers whose values are <= <cur_time>.
+ // Run the <functor> for all timers whose values are <= @a current_time.
// This does not account for <timer_skew>. Returns the number of
// timers canceled.